@@ -12,6 +12,9 @@ from .rtcconfiguration import RTCIceServer
 
 STUN_REGEX = re.compile(
     r"(?P<scheme>stun|stuns)\:(?P<host>[^?:]+)(\:(?P<port>[0-9]+?))?"
+    # RFC 7064 does not define a "transport" option but some providers
+    # include it, so just ignore it
+    r"(\?transport=.*)?"
 )
 TURN_REGEX = re.compile(
     r"(?P<scheme>turn|turns)\:(?P<host>[^?:]+)(\:(?P<port>[0-9]+?))?"
