@@ -88,8 +88,9 @@ def find_common_codecs(
     for c in remote_codecs:
         # for RTX, check we accepted the base codec
         if is_rtx(c):
-            if c.parameters.get("apt") in common_base:
-                base = common_base[c.parameters["apt"]]
+            apt = c.parameters.get("apt")
+            if isinstance(apt, int) and apt in common_base:
+                base = common_base[apt]
                 if c.clockRate == base.clockRate:
                     common.append(copy.deepcopy(c))
             continue
@@ -135,7 +136,7 @@ def is_codec_compatible(a: RTCRtpCodecParameters, b: RTCRtpCodecParameters) -> b
             # consider the absence of a profile-level-id parameter to mean
             # "constrained baseline level 3.1"
             return sdp.parse_h264_profile_level_id(
-                c.parameters.get("profile-level-id", "42E01F")
+                str(c.parameters.get("profile-level-id", "42E01F"))
             )[0]
 
         try:
@@ -311,10 +312,11 @@ class RTCPeerConnection(AsyncIOEventEmitter):
         self.__stream_id = str(uuid.uuid4())
         self.__transceivers: List[RTCRtpTransceiver] = []
 
+        self.__closeTask: Optional[asyncio.Task] = None
         self.__connectionState = "new"
         self.__iceConnectionState = "new"
         self.__iceGatheringState = "new"
-        self.__isClosed = False
+        self.__isClosed: Optional[asyncio.Future[bool]] = None
         self.__signalingState = "stable"
 
         self.__currentLocalDescription: Optional[sdp.SessionDescription] = None
@@ -474,13 +476,14 @@ class RTCPeerConnection(AsyncIOEventEmitter):
             direction=direction, kind=kind, sender_track=track
         )
 
-    async def close(self):
+    async def close(self) -> None:
         """
         Terminate the ICE agent, ending ICE processing and streams.
         """
         if self.__isClosed:
+            await self.__isClosed
             return
-        self.__isClosed = True
+        self.__isClosed = asyncio.Future()
         self.__setSignalingState("closed")
 
         # stop senders / receivers
@@ -506,7 +509,9 @@ class RTCPeerConnection(AsyncIOEventEmitter):
         # to facilitate garbage collection.
         self.remove_all_listeners()
 
-    async def createAnswer(self):
+        self.__isClosed.set_result(True)
+
+    async def createAnswer(self) -> RTCSessionDescription:
         """
         Create an SDP answer to an offer received from a remote peer during
         the offer/answer negotiation of a WebRTC connection.
@@ -571,7 +576,7 @@ class RTCPeerConnection(AsyncIOEventEmitter):
         protocol="",
         negotiated=False,
         id=None,
-    ):
+    ) -> RTCDataChannel:
         """
         Create a data channel with the given label.
 
@@ -785,7 +790,7 @@ class RTCPeerConnection(AsyncIOEventEmitter):
         # configure direction
         for t in self.__transceivers:
             if description.type in ["answer", "pranswer"]:
-                t._currentDirection = and_direction(t.direction, t._offerDirection)
+                t._setCurrentDirection(and_direction(t.direction, t._offerDirection))
 
         # gather candidates
         await self.__gather()
@@ -867,7 +872,7 @@ class RTCPeerConnection(AsyncIOEventEmitter):
                 # configure direction
                 direction = reverse_direction(media.direction)
                 if description.type in ["answer", "pranswer"]:
-                    transceiver._currentDirection = direction
+                    transceiver._setCurrentDirection(direction)
                 else:
                     transceiver._offerDirection = direction
 
@@ -924,6 +929,8 @@ class RTCPeerConnection(AsyncIOEventEmitter):
                     iceTransport._role_set = True
 
                 # set DTLS role
+                if description.type == "offer" and media.dtls.role == "client":
+                    dtlsTransport._set_role(role="server")
                 if description.type == "answer":
                     dtlsTransport._set_role(
                         role="server" if media.dtls.role == "client" else "client"
@@ -1133,8 +1140,13 @@ class RTCPeerConnection(AsyncIOEventEmitter):
             encodings: Dict[int, RTCRtpDecodingParameters] = {}
             for codec in transceiver._codecs:
                 if is_rtx(codec):
-                    if codec.parameters["apt"] in encodings and len(media.ssrc) == 2:
-                        encodings[codec.parameters["apt"]].rtx = RTCRtpRtxParameters(
+                    apt = codec.parameters.get("apt")
+                    if (
+                        isinstance(apt, int)
+                        and apt in encodings
+                        and len(media.ssrc) == 2
+                    ):
+                        encodings[apt].rtx = RTCRtpRtxParameters(
                             ssrc=media.ssrc[1].ssrc
                         )
                     continue
@@ -1177,6 +1189,14 @@ class RTCPeerConnection(AsyncIOEventEmitter):
             self.__connectionState = state
             self.emit("connectionstatechange")
 
+        # if all DTLS connections are closed, initiate a shutdown
+        if (
+            not self.__isClosed
+            and self.__closeTask is None
+            and dtlsStates == set(["closed"])
+        ):
+            self.__closeTask = asyncio.ensure_future(self.close())
+
     def __updateIceConnectionState(self) -> None:
         # compute new state
         # NOTE: we do not have "connected" or "disconnected" states
@@ -1261,8 +1281,6 @@ class RTCPeerConnection(AsyncIOEventEmitter):
                 raise ValueError("ICE username fragment or password is missing")
 
             # check DTLS role is allowed
-            if description.type == "offer" and media.dtls.role != "auto":
-                raise ValueError("DTLS setup attribute must be 'actpass' for an offer")
             if description.type in ["answer", "pranswer"] and media.dtls.role not in [
                 "client",
                 "server",
