@@ -263,6 +263,7 @@ class RTCRtpReceiver:
         if transport.state == "closed":
             raise InvalidStateError
 
+        self._enabled = True
         self.__active_ssrc: Dict[int, datetime.datetime] = {}
         self.__codecs: Dict[int, RTCRtpCodecParameters] = {}
         self.__decoder_queue: queue.Queue = queue.Queue()
@@ -450,6 +451,10 @@ class RTCRtpReceiver:
         """
         self.__log_debug("< %s", packet)
 
+        # If the receiver is disabled, discard the packet.
+        if not self._enabled:
+            return
+
         # feed bitrate estimator
         if self.__remote_bitrate_estimator is not None:
             if packet.extensions.abs_send_time is not None:
@@ -492,13 +497,16 @@ class RTCRtpReceiver:
                 self.__log_debug("x RTX packet from unknown SSRC %d", packet.ssrc)
                 return
 
-            if len(packet.payload) < 2:
+            apt = codec.parameters.get("apt")
+            if (
+                len(packet.payload) < 2
+                or not isinstance(apt, int)
+                or apt not in self.__codecs
+            ):
                 return
 
-            codec = self.__codecs[codec.parameters["apt"]]
-            packet = unwrap_rtx(
-                packet, payload_type=codec.payloadType, ssrc=original_ssrc
-            )
+            packet = unwrap_rtx(packet, payload_type=apt, ssrc=original_ssrc)
+            codec = self.__codecs[apt]
 
         # send NACKs for any missing any packets
         if self.__nack_generator is not None and self.__nack_generator.add(packet):
