@@ -3,7 +3,7 @@ import io
 from contextlib import redirect_stderr
 from unittest import TestCase
 
-from aiortc.codecs import get_decoder, get_encoder, h264
+from aiortc.codecs import get_decoder, get_encoder
 from aiortc.codecs.h264 import H264Decoder, H264Encoder, H264PayloadDescriptor
 from aiortc.jitterbuffer import JitterFrame
 from aiortc.rtcrtpparameters import RTCRtpCodecParameters
@@ -114,6 +114,7 @@ class H264Test(CodecTestCase):
         frame = self.create_video_frame(width=640, height=480, pts=0)
         packages, timestamp = encoder.encode(frame)
         self.assertGreaterEqual(len(packages), 1)
+        self.assertEqual(timestamp, 0)
 
     def test_encoder_large(self):
         encoder = get_encoder(H264_CODEC)
@@ -128,7 +129,7 @@ class H264Test(CodecTestCase):
         # delta frame
         frame = self.create_video_frame(width=1280, height=720, pts=3000)
         payloads, timestamp = encoder.encode(frame)
-        self.assertEqual(len(payloads), 1)
+        self.assertGreaterEqual(len(payloads), 1)
         self.assertEqual(timestamp, 3000)
 
         # force keyframe
@@ -146,28 +147,6 @@ class H264Test(CodecTestCase):
         self.assertEqual(payloads, [b"\x00"])
         self.assertEqual(timestamp, 90)
 
-    def test_encoder_buffering(self):
-        create_encoder_context = h264.create_encoder_context
-
-        def mock_create_encoder_context(*args, **kwargs):
-            codec, _ = create_encoder_context(*args, **kwargs)
-            return FragmentedCodecContext(codec), True
-
-        h264.create_encoder_context = mock_create_encoder_context
-        try:
-            encoder = get_encoder(H264_CODEC)
-            self.assertIsInstance(encoder, H264Encoder)
-
-            frame = self.create_video_frame(width=640, height=480, pts=0)
-            packages, timestamp = encoder.encode(frame)
-            self.assertEqual(len(packages), 0)
-
-            frame = self.create_video_frame(width=640, height=480, pts=3000)
-            packages, timestamp = encoder.encode(frame)
-            self.assertGreaterEqual(len(packages), 1)
-        finally:
-            h264.create_encoder_context = create_encoder_context
-
     def test_encoder_target_bitrate(self):
         encoder = get_encoder(H264_CODEC)
         self.assertIsInstance(encoder, H264Encoder)
@@ -213,35 +192,35 @@ class H264Test(CodecTestCase):
 
         # 3-byte start code
         packages = list(
-            H264Encoder._split_bitstream(b"\x00\x00\x01\xFF\x00\x00\x01\xFB")
+            H264Encoder._split_bitstream(b"\x00\x00\x01\xff\x00\x00\x01\xfb")
         )
-        self.assertEqual(packages, [b"\xFF", b"\xFB"])
+        self.assertEqual(packages, [b"\xff", b"\xfb"])
 
         # 4-byte start code
         packages = list(
-            H264Encoder._split_bitstream(b"\x00\x00\x00\x01\xFF\x00\x00\x00\x01\xFB")
+            H264Encoder._split_bitstream(b"\x00\x00\x00\x01\xff\x00\x00\x00\x01\xfb")
         )
-        self.assertEqual(packages, [b"\xFF", b"\xFB"])
+        self.assertEqual(packages, [b"\xff", b"\xfb"])
 
         # Multiple bytes in a packet
         packages = list(
             H264Encoder._split_bitstream(
-                b"\x00\x00\x00\x01\xFF\xAB\xCD\x00\x00\x00\x01\xFB"
+                b"\x00\x00\x00\x01\xff\xab\xcd\x00\x00\x00\x01\xfb"
             )
         )
-        self.assertEqual(packages, [b"\xFF\xAB\xCD", b"\xFB"])
+        self.assertEqual(packages, [b"\xff\xab\xcd", b"\xfb"])
 
         # Skip leading 0s
-        packages = list(H264Encoder._split_bitstream(b"\x00\x00\x00\x01\xFF"))
-        self.assertEqual(packages, [b"\xFF"])
+        packages = list(H264Encoder._split_bitstream(b"\x00\x00\x00\x01\xff"))
+        self.assertEqual(packages, [b"\xff"])
 
         # Both leading and trailing 0s
         packages = list(
             H264Encoder._split_bitstream(
-                b"\x00\x00\x00\x00\x00\x00\x01\xFF\x00\x00\x00\x00\x00"
+                b"\x00\x00\x00\x00\x00\x00\x01\xff\x00\x00\x00\x00\x00"
             )
         )
-        self.assertEqual(packages, [b"\xFF\x00\x00\x00\x00\x00"])
+        self.assertEqual(packages, [b"\xff\x00\x00\x00\x00\x00"])
 
     def test_packetize_one_small(self):
         packages = [bytes([0xFF, 0xFF])]
