@@ -4,6 +4,8 @@ from unittest import TestCase
 from unittest.mock import patch
 
 from aiortc.rtcdtlstransport import (
+    SRTP_AEAD_AES_256_GCM,
+    SRTP_AES128_CM_SHA1_80,
     RTCCertificate,
     RTCDtlsFingerprint,
     RTCDtlsParameters,
@@ -78,9 +80,13 @@ class RTCCertificateTest(TestCase):
         self.assertIsInstance(expires, datetime.datetime)
 
         fingerprints = certificate.getFingerprints()
-        self.assertEqual(len(fingerprints), 1)
+        self.assertEqual(len(fingerprints), 3)
         self.assertEqual(fingerprints[0].algorithm, "sha-256")
         self.assertEqual(len(fingerprints[0].value), 95)
+        self.assertEqual(fingerprints[1].algorithm, "sha-384")
+        self.assertEqual(len(fingerprints[1].value), 143)
+        self.assertEqual(fingerprints[2].algorithm, "sha-512")
+        self.assertEqual(len(fingerprints[2].value), 191)
 
 
 class RTCDtlsTransportTest(TestCase):
@@ -409,6 +415,28 @@ class RTCDtlsTransportTest(TestCase):
         await session1.stop()
         await session2.stop()
 
+    @asynctest
+    async def test_handshake_error_no_common_srtp_profile(self):
+        transport1, transport2 = dummy_ice_transport_pair()
+
+        certificate1 = RTCCertificate.generateCertificate()
+        session1 = RTCDtlsTransport(transport1, [certificate1])
+        session1._srtp_profiles = [SRTP_AEAD_AES_256_GCM]
+
+        certificate2 = RTCCertificate.generateCertificate()
+        session2 = RTCDtlsTransport(transport2, [certificate2])
+        session2._srtp_profiles = [SRTP_AES128_CM_SHA1_80]
+
+        await asyncio.gather(
+            session1.start(session2.getLocalParameters()),
+            session2.start(session1.getLocalParameters()),
+        )
+        self.assertEqual(session1.state, "failed")
+        self.assertEqual(session2.state, "failed")
+
+        await session1.stop()
+        await session2.stop()
+
     @asynctest
     async def test_lossy_channel(self):
         """
